@@ -26,11 +26,11 @@ def escape(s):
 
 
 def t(arg, *args, **kwargs):
-    _name = re.compile('^(\w+?)(?:\.|#|\:|$)')
+    _name = re.compile('^(\w+?)(?:\.|#|\:|\[|$)')
     _classes = re.compile('\.([a-zA-Z0-9\-_]+)')
     _id = re.compile('\#(\w+)')
     _unnamed_attrs = re.compile('\:(\w+)')
-    _named_attrs = re.compile('\[(\w+)="(.+)"\]')
+    _named_attrs = re.compile('\[(\w+)="(.*?)"\]')
 
     name = _name.findall(arg)[0]
     attributes = dict()
